import { MastraEmbedder } from './chunk-AD6IIOCI.js';
import { __name, __publicField } from './chunk-AJJZUHB4.js';
import { createOpenAI } from '@ai-sdk/openai';
import { embed as embed$1, embedMany as embedMany$1 } from 'ai';

async function embed(value, { apiKey = process.env.OPENAI_API_KEY || "", model = "text-embedding-3-small", baseURL, maxRetries = 3 }) {
  const openai = createOpenAI({
    baseURL,
    apiKey
  });
  const eModel = openai.textEmbeddingModel(model);
  return await embed$1({
    model: eModel,
    value,
    maxRetries
  });
}
__name(embed, "embed");
async function embedMany(value, { apiKey = process.env.OPENAI_API_KEY || "", model = "text-embedding-3-small", baseURL, maxRetries = 3 }) {
  const openai = createOpenAI({
    baseURL,
    apiKey
  });
  const eModel = openai.textEmbeddingModel(model);
  return await embedMany$1({
    model: eModel,
    values: value,
    maxRetries
  });
}
__name(embedMany, "embedMany");
var _OpenAIEmbedder = class _OpenAIEmbedder extends MastraEmbedder {
  constructor({ apiKey = process.env.OPENAI_API_KEY || "", model = "text-embedding-3-small", baseURL }) {
    super();
    __publicField(this, "apiKey");
    __publicField(this, "model");
    __publicField(this, "baseURL");
    this.apiKey = apiKey;
    this.model = model;
    this.baseURL = baseURL;
  }
  async embed(value, { maxRetries } = {
    maxRetries: 3
  }) {
    return embed(value, {
      apiKey: this.apiKey,
      model: this.model,
      baseURL: this.baseURL,
      maxRetries
    });
  }
  async embedMany(values, { maxRetries } = {
    maxRetries: 3
  }) {
    return embedMany(values, {
      apiKey: this.apiKey,
      model: this.model,
      baseURL: this.baseURL,
      maxRetries
    });
  }
};
__name(_OpenAIEmbedder, "OpenAIEmbedder");
var OpenAIEmbedder = _OpenAIEmbedder;

export { OpenAIEmbedder, embed, embedMany };
