import { EmbedResult, EmbedManyResult } from 'ai';
import { MastraEmbedder } from './embedder.js';

type BedrockEmbeddingModelNames = 'amazon.titan-embed-text-v1' | 'amazon.titan-embed-image-v1' | 'cohere.embed-english-v3' | 'cohere.embed-multilingual-v3' | (string & {});
declare function embed(value: string, { region, accessKeyId, secretAccessKey, sessionToken, model, maxRetries, }: {
    maxRetries?: number;
    region?: string;
    accessKeyId?: string;
    secretAccessKey?: string;
    sessionToken?: string;
    model: BedrockEmbeddingModelNames;
}): Promise<EmbedResult<string>>;
declare function embedMany(values: string[], { region, accessKeyId, secretAccessKey, sessionToken, model, maxRetries, }: {
    maxRetries?: number;
    region?: string;
    accessKeyId?: string;
    secretAccessKey?: string;
    sessionToken?: string;
    model: BedrockEmbeddingModelNames;
}): Promise<EmbedManyResult<string>>;
declare class BedrockEmbedder extends MastraEmbedder {
    region: string;
    accessKeyId: string;
    secretAccessKey: string;
    sessionToken: string;
    model: BedrockEmbeddingModelNames;
    constructor({ region, accessKeyId, secretAccessKey, sessionToken, model, }?: {
        region?: string;
        accessKeyId?: string;
        secretAccessKey?: string;
        sessionToken?: string;
        model?: BedrockEmbeddingModelNames;
    });
    embed(value: string, { maxRetries }?: {
        maxRetries?: number;
    }): Promise<EmbedResult<string>>;
    embedMany(values: string[], { maxRetries }?: {
        maxRetries?: number;
    }): Promise<EmbedManyResult<string>>;
}

export { BedrockEmbedder, type BedrockEmbeddingModelNames, embed, embedMany };
