import { EmbedResult, EmbedManyResult } from 'ai';
import { MastraEmbedder } from './embedder.js';

type CohereEmbeddingModelNames = 'embed-english-v3.0' | 'embed-english-light-v3.0' | 'embed-multilingual-v3.0' | 'embed-multilingual-light-v3.0' | (string & {});
declare function embed(value: string, { apiKey, model, baseURL, maxRetries, }: {
    maxRetries?: number;
    apiKey?: string;
    model: CohereEmbeddingModelNames;
    baseURL?: string;
}): Promise<EmbedResult<string>>;
declare function embedMany(values: string[], { apiKey, model, baseURL, maxRetries, }: {
    maxRetries?: number;
    apiKey?: string;
    model: CohereEmbeddingModelNames;
    baseURL?: string;
}): Promise<EmbedManyResult<string>>;
declare class CohereEmbedder extends MastraEmbedder {
    apiKey: string;
    model: CohereEmbeddingModelNames;
    baseURL: string | undefined;
    constructor({ apiKey, model, baseURL, }: {
        apiKey?: string;
        model: CohereEmbeddingModelNames;
        baseURL?: string;
    });
    embed(value: string, { maxRetries }?: {
        maxRetries?: number;
    }): Promise<EmbedResult<string>>;
    embedMany(values: string[], { maxRetries }?: {
        maxRetries?: number;
    }): Promise<EmbedManyResult<string>>;
}

export { CohereEmbedder, type CohereEmbeddingModelNames, embed, embedMany };
