import { EmbedResult, EmbedManyResult } from 'ai';
import { MastraEmbedder } from './embedder.js';

type GoogleEmbeddingModelNames = 'textembedding-gecko' | 'textembedding-gecko-multilingual' | (string & {});
declare function embed(value: string, { apiKey, model, baseURL, maxRetries, }: {
    maxRetries?: number;
    apiKey?: string;
    model: GoogleEmbeddingModelNames;
    baseURL?: string;
}): Promise<EmbedResult<string>>;
declare function embedMany(values: string[], { apiKey, model, baseURL, maxRetries, }: {
    maxRetries?: number;
    apiKey?: string;
    model: GoogleEmbeddingModelNames;
    baseURL?: string;
}): Promise<EmbedManyResult<string>>;
declare class GoogleEmbedder extends MastraEmbedder {
    apiKey: string;
    model: GoogleEmbeddingModelNames;
    baseURL: string | undefined;
    constructor({ apiKey, model, baseURL, }: {
        apiKey?: string;
        model: GoogleEmbeddingModelNames;
        baseURL?: string;
    });
    embed(value: string, { maxRetries }?: {
        maxRetries?: number;
    }): Promise<EmbedResult<string>>;
    embedMany(values: string[], { maxRetries }?: {
        maxRetries?: number;
    }): Promise<EmbedManyResult<string>>;
}

export { GoogleEmbedder, type GoogleEmbeddingModelNames, embed, embedMany };
