import { EmbedResult, EmbedManyResult } from 'ai';
import { MastraEmbedder } from './embedder.js';

type OpenAIEmbeddingModelNames = 'text-embedding-3-small' | 'text-embedding-3-large' | 'text-embedding-ada-002' | (string & {});
declare function embed(value: string, { apiKey, model, baseURL, maxRetries, }: {
    maxRetries?: number;
    apiKey?: string;
    model: OpenAIEmbeddingModelNames;
    baseURL?: string;
}): Promise<EmbedResult<string>>;
declare function embedMany(value: string[], { apiKey, model, baseURL, maxRetries, }: {
    maxRetries?: number;
    apiKey?: string;
    model: OpenAIEmbeddingModelNames;
    baseURL?: string;
}): Promise<EmbedManyResult<string>>;
declare class OpenAIEmbedder extends MastraEmbedder {
    apiKey: string;
    model: OpenAIEmbeddingModelNames;
    baseURL: string | undefined;
    constructor({ apiKey, model, baseURL, }: {
        apiKey?: string;
        model: OpenAIEmbeddingModelNames;
        baseURL?: string;
    });
    embed(value: string, { maxRetries }?: {
        maxRetries?: number;
    }): Promise<EmbedResult<string>>;
    embedMany(values: string[], { maxRetries }?: {
        maxRetries?: number;
    }): Promise<EmbedManyResult<string>>;
}

export { OpenAIEmbedder, type OpenAIEmbeddingModelNames, embed, embedMany };
