import { aR as MastraLLMBase, d as MastraPrimitives, aS as ToolsInput, aj as LLMTextOptions, at as CoreTool, ak as LLMTextObjectOptions, al as LLMInnerStreamOptions, am as LLMStreamObjectOptions, ai as LLMStreamOptions, af as GenerateReturn, ag as StreamReturn } from '../../index-B48181D5.js';
import * as ai from 'ai';
import { LanguageModel, Tool, CoreMessage } from 'ai';
import { JSONSchema7 } from 'json-schema';
import { ZodSchema } from 'zod';
import '../../telemetry-oCUM52DG.js';
import '../../base.js';
import '@opentelemetry/api';
import '../../index-CBZ2mk2H.js';
import 'pino';
import 'stream';
import '@opentelemetry/sdk-node';
import '@opentelemetry/sdk-trace-base';
import '../../metric-D2V4CR8D.js';
import 'sift';
import '../../embeddings/model/providers/embedder.js';
import '../../vector/index.js';
import '../../types-M16hSruO.js';
import '../../tts/index.js';

declare class MastraLLM extends MastraLLMBase {
    #private;
    constructor({ model, mastra }: {
        model: LanguageModel;
        mastra?: MastraPrimitives;
    });
    __registerPrimitives(p: MastraPrimitives): void;
    convertTools(tools?: ToolsInput): Record<string, Tool>;
    __text({ runId, messages, maxSteps, tools, convertedTools, temperature, toolChoice, onStepFinish, }: LLMTextOptions): Promise<ai.GenerateTextResult<{
        [x: string]: CoreTool;
    } | {
        [x: string]: Tool;
    }, never>>;
    __textObject<T>({ messages, onStepFinish, maxSteps, tools, convertedTools, structuredOutput, runId, temperature, }: LLMTextObjectOptions<T>): Promise<ai.GenerateObjectResult<T>>;
    __stream({ messages, onStepFinish, onFinish, maxSteps, tools, convertedTools, runId, temperature, }: LLMInnerStreamOptions): Promise<ai.StreamTextResult<{
        [x: string]: CoreTool;
    } | {
        [x: string]: Tool;
    }, never>>;
    __streamObject<T>({ messages, onStepFinish, onFinish, maxSteps, tools, convertedTools, structuredOutput, runId, temperature, }: LLMStreamObjectOptions<T>): Promise<ai.StreamObjectResult<ai.DeepPartial<T>, T, never>>;
    generate<Z extends ZodSchema | JSONSchema7 | undefined = undefined>(messages: string | string[] | CoreMessage[], { maxSteps, onStepFinish, tools, convertedTools, runId, output, temperature, }?: LLMStreamOptions<Z>): Promise<GenerateReturn<Z>>;
    stream<Z extends ZodSchema | JSONSchema7 | undefined = undefined>(messages: string | string[] | CoreMessage[], { maxSteps, onFinish, onStepFinish, tools, convertedTools, runId, output, temperature, }?: LLMStreamOptions<Z>): Promise<StreamReturn<Z>>;
}

export { MastraLLM, MastraLLMBase };
